==> acornlib-1.21.1-r8-sources.jar: net/acoyt/acornlib/impl/block/PlushBlock.java <==
package net.acoyt.acornlib.impl.block;

import com.mojang.serialization.MapCodec;
import net.acoyt.acornlib.impl.init.AcornBlockEntities;
import net.acoyt.acornlib.impl.init.AcornCriterions;
import net.acoyt.acornlib.impl.util.PlushUtils;
import net.minecraft.block.*;
import net.minecraft.class_1269;
import net.minecraft.class_1309;
import net.minecraft.class_1657;
import net.minecraft.class_1676;
import net.minecraft.class_1750;
import net.minecraft.class_1922;
import net.minecraft.class_1936;
import net.minecraft.class_1937;
import net.minecraft.class_2237;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_2415;
import net.minecraft.class_2464;
import net.minecraft.class_2470;
import net.minecraft.class_2586;
import net.minecraft.class_2591;
import net.minecraft.class_265;
import net.minecraft.class_2680;
import net.minecraft.class_2689;
import net.minecraft.class_2741;
import net.minecraft.class_2746;
import net.minecraft.class_2754;
import net.minecraft.class_3222;
import net.minecraft.class_3419;
import net.minecraft.class_3610;
import net.minecraft.class_3612;
import net.minecraft.class_3726;
import net.minecraft.class_3737;
import net.minecraft.class_3965;
import net.minecraft.class_5558;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

public class PlushBlock extends class_2237 implements class_3737 {
    private static final MapCodec<PlushBlock> CODEC = method_54094(PlushBlock::new);

    public static final class_2746 WATERLOGGED = class_2741.field_12508;
    public static final class_2754<class_2350> FACING = class_2741.field_12481;
    private static final class_265 SHAPE = method_9541(3.0F, 0.0F, 3.0F, 13.0F, 15.0F, 13.0F);

    public PlushBlock(class_2251 settings) {
        super(settings);
    }

    public MapCodec<? extends class_2237> method_53969() {
        return field_46280;
    }

    public class_2464 method_9604(class_2680 state) {
        return super.method_9604(state);
    }

    public void triggerHonk(class_1309 living) {
        if (living instanceof class_3222 serverPlayer) {
            AcornCriterions.HONK.method_9141(serverPlayer);
        }
    }

    public void method_9606(class_2680 state, class_1937 world, class_2338 pos, class_1657 player) {
        if (!world.field_9236 && world.method_8321(pos) instanceof PlushBlockEntity plush) {
            plush.squish(24);
        }
    }

    public void method_33614(class_1937 world, class_1657 player, class_2338 pos, class_2680 state) {
        triggerHonk(player);
        if (world.method_8321(pos) instanceof PlushBlockEntity plush) plush.squish(1);

        super.method_33614(world, player, pos, state);
    }

    public class_1269 method_55766(class_2680 state, class_1937 world, class_2338 pos, class_1657 player, class_3965 hit) {
        if (!world.field_9236) {
            triggerHonk(player);
            world.method_43128(null, pos.method_10263(), pos.method_10264(), pos.method_10260(), PlushUtils.getPlushSound(state), class_3419.field_15245, 1.0F, 1.0F);

            if (world.method_8321(pos) instanceof PlushBlockEntity plush) plush.squish(1);
        }

        return class_1269.field_5812;
    }

    public void method_19286(class_1937 world, class_2680 state, class_3965 hit, class_1676 projectile) {
        class_2338 pos = hit.method_17777();
        world.method_43128(null, pos.method_10263(), pos.method_10264(), pos.method_10260(), PlushUtils.getPlushSound(state), class_3419.field_15245, 1.0F, 1.0F);
        if (projectile.method_24921() != null && projectile.method_24921() instanceof class_1309 living) {
            triggerHonk(living);
        }

        if (world.method_8321(hit.method_17777()) instanceof PlushBlockEntity plush) plush.squish(1);
    }

    public class_265 method_9530(class_2680 state, class_1922 world, class_2338 pos, class_3726 context) {
        return SHAPE;
    }

    public boolean method_9526(class_2680 state) {
        return true;
    }

    @Nullable
    @Override
    public <T extends class_2586> class_5558<T> method_31645(class_1937 world, class_2680 state, class_2591<T> type) {
        return method_31618(type, AcornBlockEntities.PLUSH, PlushBlockEntity::tick);
    }

    @Nullable
    @Override
    public class_2586 method_10123(class_2338 pos, class_2680 state) {
        return new PlushBlockEntity(pos, state);
    }

    public class_2680 method_9605(@NotNull class_1750 ctx) {
        class_3610 fluidState = ctx.method_8045().method_8316(ctx.method_8037());
        return this.method_9564().method_11657(FACING, ctx.method_8042().method_10153()).method_11657(WATERLOGGED, fluidState.method_39360(class_3612.field_15910));
    }

    public class_2680 method_9598(class_2680 state, class_2470 rotation) {
        return state.method_11657(FACING, rotation.method_10503(state.method_11654(FACING)));
    }

    public class_2680 method_9569(class_2680 state, class_2415 mirror) {
        return state.method_26186(mirror.method_10345(state.method_11654(FACING)));
    }

    protected void method_9515(class_2689.class_2690<class_2248, class_2680> builder) {
        builder.method_11667(FACING, WATERLOGGED);
    }

    public class_3610 method_9545(class_2680 state) {
        return state.method_11654(WATERLOGGED) ? class_3612.field_15910.method_15729(false) : super.method_9545(state);
    }

    public class_2680 method_9559(class_2680 state, class_2350 direction, class_2680 neighborState, class_1936 world, class_2338 pos, class_2338 neighborPos) {
        if (state.method_11654(WATERLOGGED)) {
            world.method_39281(pos, class_3612.field_15910, class_3612.field_15910.method_15789(world));
        }

        return state;
    }
}

==> acornlib-1.21.5-r19-sources.jar: net/acoyt/acornlib/impl/block/PlushBlock.java <==
package net.acoyt.acornlib.impl.block;

import com.mojang.serialization.MapCodec;
import net.acoyt.acornlib.impl.index.AcornBlockEntities;
import net.acoyt.acornlib.impl.index.AcornCriterions;
import net.acoyt.acornlib.impl.util.PlushUtils;
import net.minecraft.block.*;
import net.minecraft.class_1269;
import net.minecraft.class_1309;
import net.minecraft.class_1657;
import net.minecraft.class_1676;
import net.minecraft.class_1750;
import net.minecraft.class_1922;
import net.minecraft.class_1936;
import net.minecraft.class_1937;
import net.minecraft.class_2237;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_2415;
import net.minecraft.class_2464;
import net.minecraft.class_2470;
import net.minecraft.class_2586;
import net.minecraft.class_2591;
import net.minecraft.class_265;
import net.minecraft.class_2680;
import net.minecraft.class_2689;
import net.minecraft.class_2741;
import net.minecraft.class_2746;
import net.minecraft.class_2754;
import net.minecraft.class_3222;
import net.minecraft.class_3419;
import net.minecraft.class_3610;
import net.minecraft.class_3612;
import net.minecraft.class_3726;
import net.minecraft.class_3737;
import net.minecraft.class_3965;
import net.minecraft.class_5558;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

@SuppressWarnings("unused")
public class PlushBlock extends class_2237 implements class_3737 {
    private static final MapCodec<PlushBlock> CODEC = method_54094(PlushBlock::new);

    public static final class_2746 WATERLOGGED = class_2741.field_12508;
    public static final class_2754<class_2350> FACING = class_2741.field_12481;
    private static final class_265 SHAPE = method_9541(3.0F, 0.0F, 3.0F, 13.0F, 15.0F, 13.0F);

    public PlushBlock(class_2251 settings) {
        super(settings);
    }
    
    public MapCodec<? extends class_2237> method_53969() {
        return field_46280;
    }

    public class_2464 method_9604(class_2680 state) {
        return class_2464.field_11455;
    }

    public void triggerHonk(class_1309 living) {
        if (living instanceof class_3222 serverPlayer) {
            AcornCriterions.HONK.method_9141(serverPlayer);
        }
    }

    public void method_9606(class_2680 state, class_1937 world, class_2338 pos, class_1657 player) {
        if (!world.field_9236 && world.method_8321(pos) instanceof PlushBlockEntity plush) {
            plush.squish(24);
        }
    }

    public void method_33614(class_1937 world, class_1657 player, class_2338 pos, class_2680 state) {
        triggerHonk(player);
        world.method_43128(null, pos.method_10263(), pos.method_10264(), pos.method_10260(), PlushUtils.getPlushSound(state), class_3419.field_15245, 1.0F, 1.0F);
        if (world.method_8321(pos) instanceof PlushBlockEntity plush) plush.squish(1);

        super.method_33614(world, player, pos, state);
    }

    public class_1269 method_55766(class_2680 state, class_1937 world, class_2338 pos, class_1657 player, class_3965 hit) {
        if (!world.field_9236) {
            triggerHonk(player);
            world.method_43128(null, pos.method_10263(), pos.method_10264(), pos.method_10260(), PlushUtils.getPlushSound(state), class_3419.field_15245, 1.0F, 1.0F);

            if (world.method_8321(pos) instanceof PlushBlockEntity plush) plush.squish(1);
        }

        return class_1269.field_5812;
    }

    public void method_19286(class_1937 world, class_2680 state, class_3965 hit, class_1676 projectile) {
        class_2338 pos = hit.method_17777();
        world.method_43128(null, pos.method_10263(), pos.method_10264(), pos.method_10260(), PlushUtils.getPlushSound(state), class_3419.field_15245, 1.0F, 1.0F);
        if (projectile.method_24921() != null && projectile.method_24921() instanceof class_1309 living) {
            triggerHonk(living);
        }

        if (world.method_8321(hit.method_17777()) instanceof PlushBlockEntity plush) plush.squish(1);
    }

    public class_265 method_9530(class_2680 state, class_1922 world, class_2338 pos, class_3726 context) {
        return SHAPE;
    }

    public boolean method_9526(class_2680 state) {
        return true;
    }

    @Nullable
    @Override
    public <T extends class_2586> class_5558<T> method_31645(class_1937 world, class_2680 state, class_2591<T> type) {
        return method_31618(type, AcornBlockEntities.PLUSH, PlushBlockEntity::tick);
    }

    @Nullable
    @Override
    public class_2586 method_10123(class_2338 pos, class_2680 state) {
        return new PlushBlockEntity(pos, state);
    }

    public class_2680 method_9605(@NotNull class_1750 ctx) {
        class_3610 fluidState = ctx.method_8045().method_8316(ctx.method_8037());
        return this.method_9564().method_11657(FACING, ctx.method_8042().method_10153()).method_11657(WATERLOGGED, fluidState.method_39360(class_3612.field_15910));
    }

    public class_2680 method_9598(class_2680 state, class_2470 rotation) {
        return state.method_11657(FACING, rotation.method_10503(state.method_11654(FACING)));
    }

    public class_2680 method_9569(class_2680 state, class_2415 mirror) {
        return state.method_26186(mirror.method_10345(state.method_11654(FACING)));
    }

    public void method_9515(class_2689.class_2690<class_2248, class_2680> builder) {
        builder.method_11667(FACING, WATERLOGGED);
    }

    public class_3610 method_9545(class_2680 state) {
        return state.method_11654(WATERLOGGED) ? class_3612.field_15910.method_15729(false) : super.method_9545(state);
    }

    public class_2680 getStateForNeighborUpdate(class_2680 state, class_2350 direction, class_2680 neighborState, class_1936 world, class_2338 pos, class_2338 neighborPos) {
        if (state.method_11654(WATERLOGGED)) {
            world.method_64312(pos, class_3612.field_15910, class_3612.field_15910.method_15789(world));
        }

        return state;
    }
}
